@@ -315,6 +315,27 @@ fn regex_column() {
     );
 }
 
+#[test]
+fn regex_spaces() {
+    let scanner = Scanner::new("var = / a /");
+    let mut last_end = 0;
+    for (i, item) in scanner.enumerate() {
+        let item = item.unwrap();
+        if item.token.is_eof() {
+            break;
+        }
+
+        assert_eq!(
+            1,
+            item.location.start.column - last_end,
+            "{} for {:?}",
+            i,
+            item
+        );
+        last_end = item.location.end.column;
+    }
+}
+
 #[test]
 fn regex_out_of_order() {
     pretty_env_logger::try_init().ok();
@@ -338,8 +359,21 @@ fn compare(js: &str, expectation: &[Token<&str>]) {
 }
 
 fn compare_with_position(js: &str, expectation: &[(Token<&str>, usize, usize)]) {
-    let scanner = Scanner::new(js).map(|r| r.unwrap());
-    for (i, (r, ex)) in scanner.zip(expectation.iter()).enumerate() {
+    let mut scanner = Scanner::new(js);
+    let mut i = 0;
+    let mut expectation = expectation.iter();
+    while let Some(r) = scanner.next() {
+        let r = r.unwrap();
+        if r.is_eof() {
+            return;
+        }
+        i += 1;
+        let ex = expectation
+            .next()
+            .ok_or_else(|| {
+                panic!("expectations too short for {:?}", r);
+            })
+            .unwrap();
         assert_eq!((i, &r.token), (i, &ex.0), "{:?} vs {:?}", r, ex.0);
         assert_eq!(
             (i, r.location.start.line),
